from zql.src.grammar import Grammar
from zql.src.parser import parse_ast
from zql.src.renderer import render_query
from zql.src.types import MaybeDialect


def translate(
    grammar: Grammar,
    source: str,
    source_dialect: MaybeDialect = None,
    target_dialect: MaybeDialect = None
) -> str:
    ast = parse_ast(grammar, source, source_dialect)
    target = render_query(grammar, ast, target_dialect)
    return target


from zql.src.grammar import Grammar, parse_grammar


ZQL_GRAMMAR_PATH = "zql/src/zql_grammar.tmjd"


def get_zql_grammar() -> Grammar:
    with open(ZQL_GRAMMAR_PATH, "r") as file:
        content = file.read()
        return parse_grammar(content)